package com.jiuqi.util.patterns;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/* loaded from: com_jiuqi_util_patterns.jar:com/jiuqi/util/patterns/PlaceholderPattern.class */
class PlaceholderPattern implements IPattern {
    private List items = new ArrayList();
    private String expression;
    private boolean isVariable;

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        if (this.isVariable) {
            buffer.append("${");
        }
        for (int i = 0; i < size(); i++) {
            buffer.append(get(i).toString());
        }
        if (this.isVariable) {
            buffer.append("}");
        }
        return buffer.toString();
    }

    public boolean isVariable() {
        return this.isVariable;
    }

    public void setIsVariable(boolean value) {
        this.isVariable = value;
    }

    public void parse(String expression) throws PatternException {
        clear();
        this.expression = expression;
        if (expression == null) {
            return;
        }
        int cur = 0;
        int start = 0;
        int stackSize = 0;
        boolean startVar = false;
        while (cur < expression.length()) {
            switch (charOf(cur)) {
                case '$':
                    if (charOf(cur + 1) == '{') {
                        if (startVar) {
                            stackSize++;
                        } else {
                            addConst(start, cur);
                            start = cur;
                            startVar = true;
                            stackSize = 0;
                        }
                        cur += 2;
                        break;
                    } else {
                        cur++;
                        break;
                    }
                case '}':
                    if (startVar) {
                        if (stackSize == 0) {
                            addVariable(start + 2, cur);
                            startVar = false;
                            start = cur + 1;
                        } else {
                            stackSize--;
                        }
                    }
                    cur++;
                    break;
                default:
                    cur++;
                    break;
            }
        }
        if (cur == expression.length() && cur > start) {
            addConst(start, cur);
        }
    }

    private char charOf(int index) {
        if (index < 0 || index >= this.expression.length()) {
            return (char) 0;
        }
        return this.expression.charAt(index);
    }

    private void addConst(int start, int cur) {
        if (start >= cur) {
            return;
        }
        String s = this.expression.substring(start, cur);
        ConstPattern p = new ConstPattern(s);
        add(p);
    }

    private void addVariable(int start, int cur) throws PatternException {
        if (start >= cur) {
            return;
        }
        String s = this.expression.substring(start, cur);
        int p1 = s.indexOf("${");
        int p2 = s.lastIndexOf(125);
        if (p1 >= 0 && p1 < p2) {
            PlaceholderPattern p = new PlaceholderPattern();
            p.parse(s);
            p.setIsVariable(true);
            add(p);
            return;
        }
        VariablePattern p3 = new VariablePattern();
        p3.parse(s);
        add(p3);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void add(IPattern pattern) {
        this.items.add(pattern);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void add(int index, IPattern pattern) {
        this.items.add(index, pattern);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void clear() {
        this.items.clear();
        this.expression = null;
        this.isVariable = false;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public IPattern get(int index) {
        return (IPattern) this.items.get(index);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public String getExpression() {
        return toString();
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int getLength() {
        return 0;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int getType() {
        return 1;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int indexOf(IPattern pattern) {
        return this.items.indexOf(pattern);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void remove(int index) {
        this.items.remove(index);
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void setExpression(String value) {
        try {
            parse(value);
        } catch (PatternException unused) {
            clear();
        }
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void setLength(int value) {
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int size() {
        return this.items.size();
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int match(String s, int start, Map values) {
        if (this.isVariable) {
            return -1;
        }
        int next = start;
        for (int cur = 0; cur < size(); cur++) {
            switch (get(cur).getType()) {
                case IPattern.CONST /* 0 */:
                    next = get(cur).match(s, start, values);
                    if (next == -1) {
                        return -1;
                    }
                    break;
                case IPattern.VARIABLE /* 1 */:
                    if (get(cur).getLength() > 0) {
                        next = get(cur).match(s, start, values);
                        if (next == -1) {
                            return -1;
                        }
                        String value = s.substring(start, next);
                        values.put(get(cur).getExpression(), value);
                        break;
                    } else if (cur >= size() - 1) {
                        String value2 = s.substring(start);
                        values.put(get(cur).getExpression(), value2);
                        next = s.length();
                        break;
                    } else if (get(cur + 1).getType() == 0) {
                        next = s.indexOf(get(cur + 1).getExpression(), start + 1);
                        if (next == -1) {
                            return -1;
                        }
                        String value3 = s.substring(start, next);
                        values.put(get(cur).getExpression(), value3);
                        break;
                    } else {
                        int backLen = statNextLength(cur);
                        if (backLen == -1 || start >= s.length() - backLen) {
                            return -1;
                        }
                        next = s.length() - backLen;
                        String value4 = s.substring(start, next);
                        values.put(get(cur).getExpression(), value4);
                        break;
                    }
            }
            start = next;
        }
        return start;
    }

    private int statNextLength(int cur) {
        int i;
        int length;
        int len = 0;
        for (int i2 = cur + 1; i2 < size(); i2++) {
            switch (get(i2).getType()) {
                case IPattern.CONST /* 0 */:
                    i = len;
                    length = get(i2).getLength();
                    break;
                case IPattern.VARIABLE /* 1 */:
                    if (get(i2).getLength() > 0) {
                        i = len;
                        length = get(i2).getLength();
                        break;
                    } else {
                        return -1;
                    }
                default:
                    return -1;
            }
            len = i + length;
        }
        return len;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public String replace(ITranslator translator) {
        StringBuffer buffer = new StringBuffer();
        for (int i = 0; i < size(); i++) {
            buffer.append(get(i).replace(translator));
        }
        if (this.isVariable) {
            String[] ret = translator.translate(buffer.toString(), 0);
            if (ret == null) {
                return buffer.toString();
            }
            return ret.length == 0 ? "" : ret[0];
        }
        return buffer.toString();
    }
}
